# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   Python1
# FileName:      read_excel.py
# Author:       chenyao
# Datetime:     2025/3/12 19:02
# Description:
# 
# ---------------------------------------------------------------------------
import openpyxl

from Auto_TestV4 import log_decorator
from Auto_TestV4.commom.read_ini import ReadIni
from Auto_TestV4.commom.read_json import ReadJson



class ReadExcel:
    @log_decorator
    def __init__(self):
        """获取基本数据,存放二维列表中"""
        ini=ReadIni()
        excel_path=ini.get_file_path("excel")
        case_data_path=ini.get_file_path("case")
        expect_data_path=ini.get_file_path("expect")
        sql_data_path=ini.get_file_path("sql")
        self.server_path=ini.get_server_value("host")
        table_name=ini.get_table_name("tablename")
        self.case_data_dict=ReadJson(case_data_path)
        self.expect_data_dict=ReadJson(expect_data_path)
        self.sql_data_dict=ReadJson(sql_data_path)
        wb=openpyxl.load_workbook(excel_path)
        self.ws=wb[table_name]

    @log_decorator
    def __get_cell_value(self,colomn:str,row:int) :
        value=self.ws[colomn+str(row)].value
        if isinstance(value,str) and value.strip():
            return value.strip()
    @log_decorator
    def get_module_name(self,row):
        return self.__get_cell_value("b",row)
    @log_decorator
    def get_api_name(self,row):
        return self.__get_cell_value("c",row)
    @log_decorator
    def get_title(self,row):
        return self.__get_cell_value("d",row)
    @log_decorator
    def get_level(self,row):
        return self.__get_cell_value("e",row)
    @log_decorator
    def get_method(self,row):
        return self.__get_cell_value("f",row)
    @log_decorator
    def get_case_url(self,row):
        value=self.__get_cell_value("g",row)
        if value:
            return self.server_path+value
    @log_decorator
    def get_type(self,row):
        value=self.__get_cell_value("h",row)
        if value:
            return value.lower()
    @log_decorator
    def get_case_data(self,row):
        value=self.__get_cell_value("i",row)
        if value:
            module_name=self.get_module_name(row)
            api_name=self.get_api_name(row)
            case_data=self.case_data_dict[module_name][api_name][value]
            return case_data

    @log_decorator
    def get_expect_data(self, row):
        value = self.__get_cell_value("j", row)
        if value:
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            expect_data = self.expect_data_dict[module_name][api_name][value]
            return expect_data

    @log_decorator
    def get_sql_data(self, row):
        value = self.__get_cell_value("k", row)
        if value:
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            sql_data= self.sql_data_dict[module_name][api_name][value]
            return sql_data
    @log_decorator
    def get_sql_type(self,row):
        value=self.__get_cell_value("l",row)
        if value:
            return value.lower()
    @log_decorator
    def get_updatekey(self,row):
        value=self.__get_cell_value("m",row)
        return value

    @log_decorator
    def get_all_data(self):
        data_list=[]
        for row in range(2,self.ws.max_row+1):
            req_method=self.get_method(row)
            req_url=self.get_case_url(row)
            req_type=self.get_type(row)
            req_case_data=self.get_case_data(row)
            req_expect_data=self.get_expect_data(row)
            req_sql_data=self.get_sql_data(row)
            req_sql_type=self.get_sql_type(row)
            req_updatekey=self.get_updatekey(row)
            if req_method and req_url and req_type:
                data_list.append([req_method,req_url,req_type,req_case_data,req_expect_data,req_sql_data,req_sql_type,req_updatekey])
        else:
            return data_list



if __name__ == '__main__':
   ec=ReadExcel()
   print(ec.get_all_data())





